@@ -102,7 +102,7 @@ my $RxSess = {
     }x,
 };
 
-sub version     { '4.0.13' }
+sub version     { '4.0.15' }
 sub description { 'Exim' }
 sub smtpagent   { 'Exim' }
 sub headerlist  { return [ 'X-Failed-Recipients' ] }
@@ -126,7 +126,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
 
     my $longfields = __PACKAGE__->LONGFIELDS;
-    my $stripedtxt = [ split( "\n", $$mbody ) ];
+    my @stripedtxt = split( "\n", $$mbody );
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $localhost0 = '';    # (String) Local MTA
 
@@ -135,11 +135,11 @@ sub scan {
     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     $rfc822head = __PACKAGE__->RFC822HEADERS;
 
-    for my $e ( @$stripedtxt ) {
+    for my $e ( @stripedtxt ) {
         # Read each line between $RxMTA->{'begin'} and $RxMTA->{'rfc822'}.
         if( ( $e =~ $RxMTA->{'rfc822'} ) .. ( $e =~ $RxMTA->{'endof'} ) ) {
             # After "message/rfc822"
-            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+            if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
                 my $lhs = $1;
                 my $rhs = $2;
@@ -215,11 +215,11 @@ sub scan {
         # Fallback for getting recipient addresses
         if( defined $mhead->{'x-failed-recipients'} ) {
             # X-Failed-Recipients: kijitora@example.jp
-            my $rcptinhead = [ split( ',', $mhead->{'x-failed-recipients'} ) ];
-            map { $_ =~ y/ //d } @$rcptinhead;
-            $recipients = scalar @$rcptinhead;
+            my @rcptinhead = split( ',', $mhead->{'x-failed-recipients'} );
+            map { $_ =~ y/ //d } @rcptinhead;
+            $recipients = scalar @rcptinhead;
 
-            for my $e ( @$rcptinhead ) {
+            for my $e ( @rcptinhead ) {
                 # Insert each recipient address into @$dscontents
                 $dscontents->[-1]->{'recipient'} = $e;
                 next if scalar @$dscontents == $recipients;
