@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use Class::Accessor::Lite;
 use File::Basename 'basename';
-use Try::Tiny;
 use IO::File;
 
 my $roaccessors = [
-    'data',     # (String) path to mbox
+    'path',     # (String) path to mbox
     'name',     # (String) file name of the mbox
     'size',     # (Integer) File size of the mbox
 ];
@@ -28,10 +27,9 @@ sub new {
     my $argvs = shift // return undef;
     my $param = { 'offset' => 0 };
 
-    return undef unless -e $argvs;
     return undef unless -f $argvs;
 
-    $param->{'data'}   = $argvs;
+    $param->{'path'}   = $argvs;
     $param->{'size'}   = -s $argvs;
     $param->{'name'}   = File::Basename::basename $argvs;
     $param->{'handle'} = IO::File->new( $argvs, 'r' );
@@ -49,14 +47,13 @@ sub read {
     my $filehandle = $self->{'handle'};
     my $readbuffer = '';
 
-    return undef unless defined $self->{'data'};
-    return undef unless -e $self->{'data'};
-    return undef unless -f $self->{'data'};
-    return undef unless -T $self->{'data'};
+    return undef unless defined $self->{'path'};
+    return undef unless -f $self->{'path'};
+    return undef unless -T $self->{'path'};
 
-    try {
+    eval {
         $seekoffset = 0 if $seekoffset < 0;
-        $filehandle = IO::File->new( $self->{'data'}, 'r' ) unless eof $filehandle;
+        $filehandle = IO::File->new( $self->{'path'}, 'r' ) unless eof $filehandle;
 
         seek( $filehandle, $seekoffset, 0 );
         while( my $r = <$filehandle> ) {
@@ -67,9 +64,6 @@ sub read {
         $filehandle->close;
         $seekoffset += length $readbuffer;
         $self->{'offset'} = $seekoffset;
-
-    } catch {
-        warn $_;
     };
     return $readbuffer;
 }
@@ -104,11 +98,11 @@ C<new()> is a constructor of Sisimai::Mail::Mbox
 
 =head1 INSTANCE METHODS
 
-=head2 C<B<data()>>
+=head2 C<B<path()>>
 
-C<data()> returns the path to mbox.
+C<path()> returns the path to mbox.
 
-    print $mailbox->data;   # /var/mail/root
+    print $mailbox->path;   # /var/mail/root
 
 =head2 C<B<name()>>
 
