@@ -3,11 +3,10 @@ use feature ':5.10';
 use strict;
 use warnings;
 use Class::Accessor::Lite;
-use Module::Load;
+use Module::Load '';
 use Sisimai::ARF;
 use Sisimai::MTA;
 use Sisimai::MSP;
-use Try::Tiny;
 
 my $rwaccessors = [
     'from',             # (String) UNIX From line
@@ -65,8 +64,8 @@ sub resolve {
 
     my $processing = { 'from' => '', 'header' => {}, 'rfc822' => '', 'ds' => [] };
     my $methodargv = {};
-    my $mtamodules = [];
-    my $mspmodules = [];
+    my @mtamodules = ();
+    my @mspmodules = ();
 
     for my $e ( 'mtalist', 'msplist' ) {
         # The order of MTA modules specified by user
@@ -74,13 +73,13 @@ sub resolve {
         next unless ref $argvs->{ $e } eq 'ARRAY';
         next unless scalar @{ $argvs->{ $e } };
 
-        push @$mtamodules, @{ $argvs->{'mtalist'} } if $e eq 'mtalist';
-        push @$mspmodules, @{ $argvs->{'msplist'} } if $e eq 'msplist';
+        push @mtamodules, @{ $argvs->{'mtalist'} } if $e eq 'mtalist';
+        push @mspmodules, @{ $argvs->{'msplist'} } if $e eq 'msplist';
     }
 
     # Default order of MTA modules
-    push @$mtamodules, @$DefaultMTA;
-    push @$mspmodules, @$DefaultMSP;
+    push @mtamodules, @$DefaultMTA;
+    push @mspmodules, @$DefaultMSP;
 
     EMAIL_PROCESSING: {
         my $endofheads = 0;
@@ -123,53 +122,40 @@ sub resolve {
 
         CONVERT_HEADER: {
             # 2. Convert email headers from text to hash reference
-            my $mtaclasses = [ map { 'Sisimai::MTA::'.$_ } @$mtamodules ];
-            my $mspclasses = [ map { 'Sisimai::MSP::'.$_ } @$mspmodules ];
+            my @mtaclasses = map { 'Sisimai::MTA::'.$_ } @mtamodules;
+            my @mspclasses = map { 'Sisimai::MSP::'.$_ } @mspmodules;
             my $currheader = '';
-            my $headerlist = [ 
+            my @headerlist = ( 
                 'From', 'To', 'Date', 'Subject', 'Content-Type', 'Reply-To',
                 'Message-Id', 'Received'
-            ];
-            my $multiheads = [ 'Received' ];
-            my $ignorelist = [ 'DKIM-Signature' ];
-            my $loaderrors = {};
+            );
+            my @multiheads = ( 'Received' );
+            my @ignorelist = ( 'DKIM-Signature' );
 
-            map { $processing->{'header'}->{ lc $_ } = undef } @$headerlist;
-            map { $processing->{'header'}->{ lc $_ } = [] } @$multiheads;
+            map { $processing->{'header'}->{ lc $_ } = undef } @headerlist;
+            map { $processing->{'header'}->{ lc $_ } = [] } @multiheads;
 
-            MTA_MODULES: for my $e ( @$mtaclasses ) {
+            MTA_MODULES: for my $e ( @mtaclasses ) {
                 # Load MTA modules saved in lib/Sisimai/MTA directory
-                try {
-                    Module::Load::load $e;
+                eval { Module::Load::load $e };
+                next if $@;
 
-                } catch {
-                    # Perhaps it failed to load Sisimai::MTA::*
-                    $loaderrors->{ $e } = 1;
-                };
-
-                next if $loaderrors->{ $e };
                 for my $v ( @{ $e->headerlist } ) {
                     # Get header name which required each MTA module
-                    next if grep { $v eq $_ } @$headerlist;
-                    push @$headerlist, $v;
+                    next if grep { $v eq $_ } @headerlist;
+                    push @headerlist, $v;
                 }
             }
 
-            MSP_MODULES: for my $e ( @$mspclasses ) {
+            MSP_MODULES: for my $e ( @mspclasses ) {
                 # Load MSP modules saved in lib/Sisimai/MSP directory
-                try {
-                    Module::Load::load $e;
+                eval { Module::Load::load $e };
+                next if $@;
 
-                } catch {
-                    # Perhaps it failed to load Sisimai::MSP::*
-                    $loaderrors->{ $e } = 1;
-                };
-
-                next if $loaderrors->{ $e };
                 for my $v ( @{ $e->headerlist } ) {
                     # Get header name which required each MSP module
-                    next if grep { $v eq $_ } @$headerlist;
-                    push @$headerlist, $v;
+                    next if grep { $v eq $_ } @headerlist;
+                    push @headerlist, $v;
                 }
             }
 
@@ -177,26 +163,26 @@ sub resolve {
 
                 if( $e =~ m/\A([^ ]+?)[:][ ]*(.+?)\z/ ) {
                     # split the line into a header name and a header content
-                    my $x = $1;
-                    my $y = $2;
+                    my $lhs = $1;
+                    my $rhs = $2;
 
-                    $currheader = lc $x;
-                    next unless grep { $currheader eq lc $_ } @$headerlist;
+                    $currheader = lc $lhs;
+                    next unless grep { $currheader eq lc $_ } @headerlist;
 
-                    if( grep { $currheader eq lc $_ } @$multiheads ) {
+                    if( grep { $currheader eq lc $_ } @multiheads ) {
                         # Such as 'Received' header, there are multiple headers
                         # in a single email message.
-                        $y =~ y{\t}{ };
-                        $y =~ y{ }{}s;
-                        push @{ $processing->{'header'}->{ $currheader } }, $y;
+                        $rhs =~ y/\t/ /;
+                        $rhs =~ y/ //s;
+                        push @{ $processing->{'header'}->{ $currheader } }, $rhs;
 
                     } else {
-                        $processing->{'header'}->{ $currheader } = $y;
+                        $processing->{'header'}->{ $currheader } = $rhs;
                     }
 
                 } elsif( $e =~ m/\A[\s\t]+(.+?)\z/ ) {
                     # Ignore header?
-                    next if grep { $currheader eq lc $_ } @$ignorelist;
+                    next if grep { $currheader eq lc $_ } @ignorelist;
 
                     # Header line continued from the previous line
                     if( ref $processing->{'header'}->{ $currheader } eq 'ARRAY' ) {
@@ -228,13 +214,13 @@ sub resolve {
 
             # Convert from string to hash reference
             my $v          = $bouncedata->{'rfc822'} // $bodystring;
-            my $rfc822text = [ split( "\n", $v ) ];
+            my @rfc822text = split( "\n", $v );
             my $rfc822head = Sisimai::MTA->RFC822HEADERS;
             my $previousfn = ''; # Previous field name
             my $borderline = '__MIME_ENCODED_BOUNDARY__';
             my $mimeborder = {};
 
-            for my $e ( @$rfc822text ) {
+            for my $e ( @rfc822text ) {
                 # Header name as a key, The value of header as a value
                 if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
                     # Header
@@ -328,8 +314,8 @@ sub rewrite {
         # Get the original text when the subject begins from 'fwd:' or 'fw:'
         if( $mailheader->{'subject'} =~ m/\A\s*fwd?:/i ) {
             # Delete quoted strings, quote symbols(>)
-            $$bodystring =~ s{^[>]+[ ]}{}gm;
-            $$bodystring =~ s{^[>]$}{}gm;
+            $$bodystring =~ s/^[>]+[ ]//gm;
+            $$bodystring =~ s/^[>]$//gm;
         }
     }
 
@@ -337,7 +323,7 @@ sub rewrite {
         # 1. Sisimai::ARF 
         # 2. Sisimai::MTA::*
         # 3. Sisimai::MSP::*
-        # 4. Sisimai::RFc3464
+        # 4. Sisimai::RFC3464
         #
         if( Sisimai::ARF->is_arf( $mailheader->{'content-type'} ) ) {
             # Feedback Loop message
