@@ -277,6 +277,7 @@ my $StandardCode = {
         'exceedlimit'   => [ '4.2.3' ],
         'systemfull'    => [ '4.3.1' ],
         'systemerror'   => [ '4.3.5' ],
+        'networkerror'  => [ '4.4.2', '4.4.4', '4.4.6' ],
         'expired'       => [ '4.4.7', '4.4.1' ],
     },
     'permanent' => {
@@ -291,7 +292,8 @@ my $StandardCode = {
         'systemfull'    => [ '5.3.1' ],
         'notaccept'     => [ '5.3.2' ],
         'mesgtoobig'    => [ '5.3.4' ],
-        'systemerror'   => [ '5.3.5', '5.3.0', '5.4.0', '5.4.1', '5.4.2', '5.4.3', '5.4.4', '5.4.5', '5.4.6',],
+        'systemerror'   => [ '5.3.5', '5.3.0', '5.4.1', '5.4.3', '5.4.5' ],
+        'networkerror'  => [ '5.4.0', '5.4.2', '5.4.4', '5.4.6' ],
         'expired'       => [ '5.4.7' ],
         'mailererror'   => [ '5.2.4' ],
         'contenterror'  => [ '5.6.0' ],
@@ -323,6 +325,7 @@ my $InternalCode = {
         'notaccept'     => [ '5.0.932' ],
         'mesgtoobig'    => [ '5.0.934' ],
         'systemerror'   => [ '5.0.935' ],
+        'networkerror'  => [ '5.0.946' ],
         'expired'       => [ '5.0.947' ],
         'contenterror'  => [ '5.0.960' ],
         'securityerror' => [ '5.0.970' ],
