@@ -40,7 +40,6 @@ my $MonthName = {
         'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
         'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec',
     ],
-    'rx-abbr' => qr/\A(?:Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\z/,
 };
 
 my $DayOfWeek = {
@@ -49,7 +48,6 @@ my $DayOfWeek = {
         'Friday', 'Saturday',
     ],
     'abbr' => [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', ],
-    'rx-abbr' => qr/\A(?:Sun|Mon|Tue|Wed|Thu|Fri|Sat)\z/,
 };
 
 my $HourName = {
@@ -292,7 +290,7 @@ sub parse {
     my $argvs = shift || return undef;
 
     my $datestring = $argvs; $datestring =~ s{[,](\d+)}{, $1};  # Thu,13 -> Thu, 13
-    my $timetokens = [ split( ' ', $datestring ) ];
+    my @timetokens = split( ' ', $datestring );
     my $parseddate = '';    # (String) Canonified Date/Time string
     my $afternoon1 = 0;     # (Integer) After noon flag
     my $v = {
@@ -304,17 +302,17 @@ sub parse {
         'z' => undef,   # (Integer) Timezone offset
     };
 
-    while( my $p = shift @$timetokens ) {
+    while( my $p = shift @timetokens ) {
         # Parse each piece of time
         if( $p =~ m/\A[A-Z][a-z]{2}[,]?\z/ ) {
             # Day of week or Day of week; Thu, Apr, ...
             chop $p if length( $p ) == 4; # Thu, -> Thu
 
-            if( $p =~ $DayOfWeek->{'rx-abbr'} ) {
+            if( grep { $p eq $_ } @{ $DayOfWeek->{'abbr'} } ) {
                 # Day of week; Mon, Thu, Sun,...
                 $v->{'a'} = $p;
 
-            } elsif( $p =~ $MonthName->{'rx-abbr'} ) {
+            } elsif( grep { $p eq $_ } @{ $MonthName->{'abbr'} } ) {
                 # Month name abbr.; Apr, May, ...
                 $v->{'M'} = $p;
             }
@@ -396,9 +394,9 @@ sub parse {
     if( $v->{'T'} && $afternoon1 ) {
         # +12
         my $t0 = $v->{'T'};
-        my $t1 = [ split( ':', $v->{'T'} ) ];
-        $v->{'T'} = sprintf( "%02d:%02d:%02d", $t1->[0] + 12, $t1->[1], $t1->[2] );
-        $v->{'T'} = $t0 if $t1->[0] > 12;
+        my @t1 = split( ':', $v->{'T'} );
+        $v->{'T'} = sprintf( "%02d:%02d:%02d", $t1[0] + 12, $t1[1], $t1[2] );
+        $v->{'T'} = $t0 if $t1[0] > 12;
     }
 
     $v->{'a'} ||= 'Thu';   # There is no day of week
